@@ -9,6 +9,7 @@
 #include "config.h"
 
 #ifdef _WIN32
+#include <windows.h>
 #define flockfile(x)
 #define funlockfile(x)
 #define getc_unlocked(x) getc(x)
@@ -299,7 +300,7 @@ int is_binary(const void *buf, const size_t buf_len) {
         return 0;
     }
 
-    if (buf_len >= 4 && strncmp(buf, "%PDF-", 5) == 0) {
+    if (buf_len >= 5 && strncmp(buf, "%PDF-", 5) == 0) {
         /* PDF. This is binary. */
         return 1;
     }
@@ -379,7 +380,7 @@ int binary_search(const char *needle, char **haystack, int start, int end) {
         return -1;
     }
 
-    mid = (start + end) / 2; /* can screw up on arrays with > 2 billion elements */
+    mid = start + ((end - start) / 2);
 
     rc = strcmp(needle, haystack[mid]);
     if (rc < 0) {
@@ -435,13 +436,20 @@ int is_directory(const char *path, const struct dirent *d) {
         free(full_path);
         return FALSE;
     }
+#ifdef _WIN32
+    int is_dir = GetFileAttributesA(full_path) & FILE_ATTRIBUTE_DIRECTORY;
+#else
+    int is_dir = S_ISDIR(s.st_mode);
+#endif
     free(full_path);
-    return S_ISDIR(s.st_mode);
+    return is_dir;
 }
 
 int is_symlink(const char *path, const struct dirent *d) {
 #ifdef _WIN32
-    return 0;
+    char full_path[MAX_PATH + 1] = { 0 };
+    sprintf(full_path, "%s\\%s", path, d->d_name);
+    return (GetFileAttributesA(full_path) & FILE_ATTRIBUTE_REPARSE_POINT);
 #else
 #ifdef HAVE_DIRENT_DTYPE
     /* Some filesystems, e.g. ReiserFS, always return a type DT_UNKNOWN from readdir or scandir. */
